.onLoad <- function(lib, pkg) {
       warning("package regtest is under development and still may change considerably")
}
